@@ -6,12 +6,13 @@ from collections import defaultdict
 import numpy as np
 import pandas as pd
 from PIL import Image
-from keras.layers import Dense, Flatten, MaxPooling1D, Conv1D
-from keras.layers import Embedding
-from keras.models import Sequential
-from keras.models import model_from_json
-from keras.preprocessing.sequence import pad_sequences
-from keras.preprocessing.text import Tokenizer
+import tensorflow as tf
+from tensorflow.keras.layers import Dense, Flatten, MaxPooling1D, Conv1D
+from tensorflow.keras.layers import Embedding
+from tensorflow.keras.models import Sequential
+from tensorflow.keras.models import model_from_json
+from tensorflow.keras.preprocessing.sequence import pad_sequences
+from tensorflow.keras.preprocessing.text import Tokenizer
 from keras.utils import np_utils
 from keras.utils.vis_utils import plot_model
 
@@ -269,7 +270,7 @@ def RETRAIN_MODEL_FROM_SCRATCH():
 
     regular(string_list, class_labels_norm, finalSequence_)
 
-
+@tf.autograph.experimental.do_not_convert
 def PROCESS_IMAGE(sample_name_list, path_, red_square):
     """
     Accept the image file name from LeafAreaCalculator and prcoess the passed image by cobverting it to model input vector and processing all pixels in the image.
