@@ -2,11 +2,13 @@ from os.path import relpath
 from tkinter import *
 from tkinter import filedialog
 from tkinter import ttk, messagebox
+import tensorflow as tf
 
 from PIL import ImageTk
 
 #CHange to local .basefunctions during deployment
-from .basefunctions import *
+from basefunctions import *
+from ReadBarcodes import getBarcode
 
 class LeafAreaCalculatorGUI:
     """
@@ -34,9 +36,12 @@ class LeafAreaCalculatorGUI:
         Sets parameters and configurations to default.
         :type root: Tk()
         """
+		
+        self.list_ = list()
         self.root = root
         self.current_page = IntVar()
         self.stored_area_dict = dict()
+        self.stored_barcode_dict = dict()
 
         self.current_image_name = None
         self.font = 'Helvetica'
@@ -78,6 +83,7 @@ class LeafAreaCalculatorGUI:
 
         toolsmenu.add_separator()
         toolsmenu.add_command(label='View Recent Result', command=self.view_results)
+        toolsmenu.add_command(label='Save Recent Results As CSV', command=self.save_results)
 
         helpmenu = Menu(menu)
         menu.add_cascade(label="Help", menu=helpmenu)
@@ -127,6 +133,7 @@ class LeafAreaCalculatorGUI:
         originalonly = not self.process_clicked
 
         self.label_image_name['text'] = passed_image
+        self.show_barcode['text'] = self.stored_barcode_dict[passed_image]
 
         # Original Preview Pane
         image = Image.open(os.path.join(self.default_image_path, passed_image))
@@ -202,7 +209,10 @@ class LeafAreaCalculatorGUI:
         print('EVery: ', every)
         self.stored_area_dict[every] = round(self.area_green_leaf, 2)
 
+        self.stored_barcode_dict[every] = getBarcode(os.path.join(self.default_image_path , every))
+
         analysis_info[1] = round(analysis_info[1], 2)
+        analysis_info.append(self.stored_barcode_dict[every])
         self.all_results.append(analysis_info)
 
         # Now that image analysis is complete, load the transformed image to Label2
@@ -256,7 +266,7 @@ class LeafAreaCalculatorGUI:
                 # Save results
                 dataFrameMeasure = pd.DataFrame(self.all_results,
                                                 columns=['Sample', 'Area', 'Red Pixels', 'Red Ratio', 'Green Pixels',
-                                                         'Dimensions'])
+                                                         'Dimensions', 'BarCode'])
                 dataFrameMeasure.to_csv(os.path.join(os.path.dirname(__file__), 'storedMeasuredValues.csv'))
             except Exception:
                 pass
@@ -294,6 +304,20 @@ class LeafAreaCalculatorGUI:
         Label(self.result_frame, text="", font=("Arial", 30)).grid(row=storedAreas.shape[0] + 2,
                                                                    columnspan=storedAreas.shape[1] + 2)
 
+
+    def save_results(self):
+        '''
+        Function to display the save recent results to location of user choise.
+        Displays results available in storedMeasuredValues.csv data file.
+        '''
+        import shutil
+
+        # storedAreas = pd.read_csv(os.path.join(os.path.dirname(__file__), 'storedMeasuredValues.csv'))
+        savePath = filedialog.askdirectory(initialdir=self.default_image_path)
+
+        shutil.copy(os.path.join(os.path.dirname(__file__), 'storedMeasuredValues.csv'), savePath)
+        messagebox.showinfo("File Saved", "Success:\n Results Location: "+savePath)
+
     def change_unit(self, event):
         """
         Function that allows the numerical leaf area result to switch between cm^2 and mm^2.
@@ -348,6 +372,7 @@ class LeafAreaCalculatorGUI:
         print('Val: ', val)
         self.progress.update()
 
+    @tf.autograph.experimental.do_not_convert
     def process_all(self):
         """
         Function that is triggered when Batch Process feature is activated by user.
@@ -391,10 +416,11 @@ class LeafAreaCalculatorGUI:
         else:
             messagebox.showwarning("Default Path", "Default Image Path was not set. Use File->Set Default Image Folder")
 
+    @tf.autograph.experimental.do_not_convert
     def process_image(self, every=None):
         """
         Function that accepts only one image name as input, and performs analysis.
-        Updates the Leaf Area and preview panes as the result become available. If no input is provides, iteratively processes all images in the global list_ maintained by class as list of all
+        Updates the Leaf Area and preview panes as the result become available. If no input is provides, iteratively processes all images in the list maintained by class as list of all
         images in the default image path.
 
         :param every: Image name to process
@@ -408,6 +434,7 @@ class LeafAreaCalculatorGUI:
             every = self.current_image_name
             self.label2.after(100, self.change_result_preview, every)
             self.show_area.after(100, self.display_result)
+            self.show_barcode.after(100, self.display_barcode, every)
         else:
             self.new_winF()
             for index, every in enumerate(self.list_):
@@ -415,6 +442,13 @@ class LeafAreaCalculatorGUI:
                 self.progress.after(5000, self.change_progress)
                 self.label2.after(5000, self.change_result_preview, every)
                 self.show_area.after(5000, self.display_result)
+                self.show_barcode.after(100, self.display_barcode, every)
+
+
+    def display_barcode(self,filename):
+        self.barcode = getBarcode(os.path.join(self.default_image_path , filename))
+        self.show_barcode.config(text='{}'.format(self.barcode))
+
 
     # Ask the user to select a one or more file names.
     def answer(self, x):
@@ -552,6 +586,12 @@ class LeafAreaCalculatorGUI:
         self.show_area.bind("<Button-1>", self.change_unit)
         self.show_area.place(x=600, y=370)
 
+        self.barcode_label = Label(self.my_frame, text='Barcode ID:', width=30, font=self.font_param)
+        self.barcode_label.place(x=450, y=390)
+
+        self.show_barcode = Label(self.my_frame, text='NA', width=20, font=self.font_param)
+        self.show_barcode.place(x=600, y=390)
+
         self.reset_button = Button(self.my_frame, text='Reset Workspace', height=1, width=15,
                                    command=self.reset_workspace,
                                    font=self.font_param)
